package com.ruoyi.programManagement.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.programManagement.entity.BAdministrative;
import com.ruoyi.programManagement.entity.request.BAdministrativeTreeRequest;
import com.ruoyi.programManagement.service.IBAdministrativeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;

/**
 * 行政区划Controller
 *
 * @author ruoyi
 * @date 2023-09-11
 */
@Api(tags = "行政区划")
@Transactional(rollbackFor = Exception.class)
@RestController
@RequestMapping("/pharmaceuticals/administrative")
public class BAdministrativeController extends BaseController {
    @Autowired
    private IBAdministrativeService bAdministrativeService;

    /**
     * 查询行政区划列表
     */
    @GetMapping("/list")
    public TableDataInfo list(BAdministrative bAdministrative) {
        startPage();
        List<BAdministrative> list = bAdministrativeService.selectBAdministrativeList(bAdministrative);
        return getDataTable(list);
    }

    /**
     * 导出行政区划列表
     */
    @PostMapping("/export")
    public void export(HttpServletResponse response, BAdministrative bAdministrative) {
        List<BAdministrative> list = bAdministrativeService.selectBAdministrativeList(bAdministrative);
        ExcelUtil<BAdministrative> util = new ExcelUtil<BAdministrative>(BAdministrative.class);
        util.exportExcel(response, list, "行政区划数据");
    }

    /**
     * 获取行政区划详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bAdministrativeService.selectBAdministrativeById(id));
    }

    /**
     * 新增行政区划
     */

    @PostMapping
    public AjaxResult add(@RequestBody BAdministrative bAdministrative) {
        return toAjax(bAdministrativeService.insertBAdministrative(bAdministrative));
    }

    /**
     * 修改行政区划
     */
    @PutMapping
    public AjaxResult edit(@RequestBody BAdministrative bAdministrative) {
        return toAjax(bAdministrativeService.updateBAdministrative(bAdministrative));
    }

    /**
     * 删除行政区划
     */
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bAdministrativeService.deleteBAdministrativeByIds(ids));
    }

    /**
     * 行政区划树结构
     */
    @ApiOperation(value = "行政区划树结构")
    @GetMapping("/tree")
    public AjaxResult tree() {
        List<BAdministrativeTreeRequest> list = bAdministrativeService.selectBAdministrativeTreeRequestList();
        List<BAdministrativeTreeRequest> listsub = bAdministrativeService.selectcascadingSelectDataList();
        List<BAdministrativeTreeRequest> cascadingSelectData = new ArrayList<>();
        for (BAdministrativeTreeRequest item1 : list) {
            BAdministrativeTreeRequest parentDto = new BAdministrativeTreeRequest(item1.getCounty(), item1.getSubdistrict(), item1.getInstitutionName());
            for (BAdministrativeTreeRequest item2 : listsub) {
                if (item2.getSubdistrict()!=null && !item2.getSubdistrict().equals("")){
                    if (item2.getSubdistrict().substring(0, 7).equals(item1.getCounty().substring(0, 7))) {
                        BAdministrativeTreeRequest childDto = new BAdministrativeTreeRequest(item2.getCounty(), item2.getSubdistrict(), item2.getInstitutionName());
                        parentDto.addChild(childDto);
                    }
                }
            }
            cascadingSelectData.add(parentDto);
        }
        return success(cascadingSelectData);
    }

}
